@@ -30,16 +30,16 @@ extern "C" {
 #define MagickLibVersion  0x69C
 #define MagickLibVersionText  "6.9.12"
 #define MagickLibVersionNumber  7,0,0
-#define MagickLibAddendum  "-19"
+#define MagickLibAddendum  "-38"
 #define MagickLibInterface  7
 #define MagickLibMinInterface  7
-#define MagickPlatform  "powerpc64"
+#define MagickPlatform  "aarch64"
 #define MagickppLibVersionText  "6.9.12"
 #define MagickppLibVersionNumber  9:0:0
-#define MagickppLibAddendum  "-19"
+#define MagickppLibAddendum  "-38"
 #define MagickppLibInterface  9
 #define MagickppLibMinInterface  9
-#define MagickReleaseDate  ""
+#define MagickReleaseDate  "2022-02-05"
 #define MagickHomeURL  "file:///usr/local/share/doc/ImageMagick/index.html"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
@@ -60,10 +60,15 @@ extern "C" {
 #define MagickQuantumDepth  "Q?"
 #define MagickQuantumRange  "?"
 #endif
+#if defined(MAGICKCORE_HDRI_SUPPORT)
+#define MagickHDRISupport  "-HDRI"
+#else
+#define MagickHDRISupport  ""
+#endif
 #define MagickVersion  \
   MagickPackageName " " MagickLibVersionText MagickLibAddendum " " \
-  MagickQuantumDepth " " MagickPlatform " " MagickReleaseDate " " \
-  MagickAuthoritativeURL
+  MagickQuantumDepth MagickHDRISupport " " MagickPlatform " " \
+  MagickReleaseDate " " MagickAuthoritativeURL
 
 extern MagickExport char
   *GetMagickHomeURL(void);
